{% load static %}

{% if avoid_cdn %}
    <link href={% static 'aasrp/libs/x-editable/1.5.0/bootstrap3-editable/css/bootstrap-editable.min.css' %} rel="stylesheet">
{% else %}
    <link href="//cdnjs.cloudflare.com/ajax/libs/x-editable/1.5.0/bootstrap3-editable/css/bootstrap-editable.css" rel="stylesheet">
{% endif %}
