{% load i18n %}

<!-- request actions modal -->
<div class="modal fade" id="srp-request-accept" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="{% translate 'Close' %}">
                    <span aria-hidden="true">&times;</span>
                </button>

                <div class="modal-title">{% translate 'Accept SRP Request' %}</div>
            </div>

            <div class="modal-body"></div>

            <div class="modal-footer">
                <button id="modal-button-cancel-accept-request" type="button" class="btn btn-default btn-sm" data-dismiss="modal"></button>
                <button id="modal-button-confirm-accept-request" type="button" data-dismiss="modal"></button>
            </div>
        </div>
    </div>
</div>
